@@ -416,7 +416,8 @@ class Imager:
         pcolormesh_kwargs: dict = {},
     ) -> Tuple[plt.Axes, matplotlib.collections.QuadMesh]:
         """
-        Projects the ASI images to a map at an altitude defined in the skymap calibration file.
+        Projects an ASI image onto a map at an altitude that is defined in the skymap calibration 
+        file.
 
         Parameters
         ----------
@@ -1453,6 +1454,8 @@ class Imager:
             color_norm = colors.LogNorm(vmin=color_bounds[0], vmax=color_bounds[1])
         elif color_norm == 'lin':
             color_norm = colors.Normalize(vmin=color_bounds[0], vmax=color_bounds[1])
+        elif isinstance(color_norm, matplotlib.colors.Normalize):
+            pass
         else:
             raise ValueError(f'color_norm must be either None, "log", or "lin", not {color_norm=}.')
 
